pub struct ClientConfig {
pub channel_capacity: usize,
pub max_retry_attempts: i32,
pub retry_connection: Duration,
pub request_timeout: Duration,
pub bearer_token: Option<String>,
pub ws_config: WebSocketConfig,
}Expand description
The config used for Client.
Controls the timeout Durations, max retry attempts, etc.
Also contains the WebSocketConfig for the underlying socket.
Fields
channel_capacity: usizeHow many messages can be in any of the internal channels at once.
max_retry_attempts: i32How many reconnection attempts the client will attempt at most when connection is lost.
retry_connection: DurationThe delay between each reconnection attempt.
request_timeout: DurationThe timeout for each request to the server.
bearer_token: Option<String>An optional bearer token that will be added into a Authorization header on connection.
ws_config: WebSocketConfigConfig for the underlying websocket.
Implementations
Sourceimpl ClientConfig
impl ClientConfig
Sourcepub fn with_bearer(bearer: &str) -> ClientConfig
pub fn with_bearer(bearer: &str) -> ClientConfig
Creates a default ClientConfig but with a bearer_token supplied.